? .DS_Store
? node-tpl-php-new5.patch
? modules/.DS_Store
? modules/node/.DS_Store
? sites/default/files
? sites/default/settings.php
Index: modules/node/node.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/node/node.tpl.php,v
retrieving revision 1.13
diff -u -p -r1.13 node.tpl.php
--- modules/node/node.tpl.php	18 Jun 2009 21:19:02 -0000	1.13
+++ modules/node/node.tpl.php	21 Jun 2009 06:16:37 -0000
@@ -12,8 +12,7 @@
  *   hide($content['field_example]) to temporarily suppress the printing of a 
  *   given element.
  * - $comments: the themed list of comments (if any).
- * - $picture: The authors picture of the node output from
- *   theme_user_picture().
+ * - $picture: The author's picture (passed from user-picture.tpl.php).
  * - $date: Formatted creation date (use $created to reformat with
  *   format_date()).
  * - $links: Themed links like "Read more", "Add new comment", etc. output
@@ -70,21 +69,23 @@
 ?>
 <div id="node-<?php print $node->nid; ?>" class="<?php print $classes ?> clearfix">
 
-<?php print $picture ?>
+  <?php print $picture ?>
 
-<?php if (!$page): ?>
-  <h2><a href="<?php print $node_url ?>"><?php print $title ?></a></h2>
-<?php endif; ?>
-
-  <div class="meta">
-  <?php if ($submitted): ?>
-    <span class="submitted"><?php print $submitted ?></span>
+  <?php if (!$page): ?>
+    <h2><a href="<?php print $node_url ?>"><?php print $title ?></a></h2>
   <?php endif; ?>
 
-  <?php if (!empty($content['links']['terms'])): ?>
-    <div class="terms terms-inline"><?php render($content['links']['terms']) ?></div>
-  <?php endif;?>
-  </div>
+  <?php if ($submitted || !empty($content['links']['terms'])): ?>
+    <div class="meta">
+      <?php if ($submitted): ?>
+        <span class="submitted"><?php print $submitted ?></span>
+      <?php endif; ?>
+
+      <?php if (!empty($content['links']['terms'])): ?>
+        <div class="terms terms-inline"><?php render($content['links']['terms']) ?></div>
+      <?php endif; ?>
+    </div>
+  <?php endif; ?>
 
   <div class="content">
     <?php
Index: modules/user/user-rtl.css
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user-rtl.css,v
retrieving revision 1.4
diff -u -p -r1.4 user-rtl.css
--- modules/user/user-rtl.css	8 Apr 2008 22:50:55 -0000	1.4
+++ modules/user/user-rtl.css	21 Jun 2009 06:16:37 -0000
@@ -11,7 +11,7 @@
   clear: left;
 }
 
-.profile .picture {
+.profile .user-picture {
   float: left;
   margin: 0 0 1em 1em;
 }
Index: modules/user/user.css
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user.css,v
retrieving revision 1.11
diff -u -p -r1.11 user.css
--- modules/user/user.css	14 Jun 2009 08:04:25 -0000	1.11
+++ modules/user/user.css	21 Jun 2009 06:16:38 -0000
@@ -33,7 +33,7 @@
   clear: both;
   margin: 1em 0;
 }
-.profile .picture {
+.profile .user-picture {
   float: right; /* LTR */
   margin: 0 1em 1em 0; /* LTR */
 }
Index: modules/user/user.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user.module,v
retrieving revision 1.1001
diff -u -p -r1.1001 user.module
--- modules/user/user.module	13 Jun 2009 20:40:09 -0000	1.1001
+++ modules/user/user.module	21 Jun 2009 06:16:39 -0000
@@ -1178,7 +1178,7 @@ function user_block_view($delta = '') {
  * @see user-picture.tpl.php
  */
 function template_preprocess_user_picture(&$variables) {
-  $variables['picture'] = '';
+  $variables['user_picture'] = '';
   if (variable_get('user_pictures', 0)) {
     $account = $variables['account'];
     if (!empty($account->picture)) {
@@ -1201,10 +1201,10 @@ function template_preprocess_user_pictur
     }
     if (isset($filepath)) {
       $alt = t("@user's picture", array('@user' => $account->name ? $account->name : variable_get('anonymous', t('Anonymous'))));
-      $variables['picture'] = theme('image', $filepath, $alt, $alt, '', FALSE);
+      $variables['user_picture'] = theme('image', $filepath, $alt, $alt, '', FALSE);
       if (!empty($account->uid) && user_access('access user profiles')) {
         $attributes = array('attributes' => array('title' => t('View user profile.')), 'html' => TRUE);
-        $variables['picture'] = l($variables['picture'], "user/$account->uid", $attributes);
+        $variables['user_picture'] = l($variables['user_picture'], "user/$account->uid", $attributes);
       }
     }
   }
Index: themes/garland/style-rtl.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style-rtl.css,v
retrieving revision 1.13
diff -u -p -r1.13 style-rtl.css
--- themes/garland/style-rtl.css	3 Jun 2009 06:58:57 -0000	1.13
+++ themes/garland/style-rtl.css	21 Jun 2009 06:16:39 -0000
@@ -169,7 +169,7 @@ ul.links li, ul.inline li {
   padding-left: 0;
 }
 
-.picture, .comment .submitted {
+.user-picture, .comment .submitted {
   padding-left: 0;
   float: left;
   clear: left;
Index: themes/garland/style.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style.css,v
retrieving revision 1.57
diff -u -p -r1.57 style.css
--- themes/garland/style.css	31 May 2009 00:51:41 -0000	1.57
+++ themes/garland/style.css	21 Jun 2009 06:16:39 -0000
@@ -673,7 +673,7 @@ ul.links li, ul.inline li {
   padding-left: 1em;
 }
 
-.picture, .comment .submitted {
+.user-picture, .comment .submitted {
   float: right; /* LTR */
   clear: right; /* LTR */
   padding-left: 1em; /* LTR */

Index: modules/user/user-picture.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user-picture.tpl.php,v
retrieving revision 1.4
diff -u -p -r1.4 user-picture.tpl.php
--- modules/user/user-picture.tpl.php	24 Apr 2009 09:03:21 -0000	1.4
+++ modules/user/user-picture.tpl.php	21 Jun 2009 06:16:37 -0000
@@ -7,7 +7,7 @@
  * user's account.
  *
  * Available variables:
  * - $picture: Image set by the user or the site's default. Will be linked
  *   depending on the viewer's permission to view the users profile page.
  * - $account: Array of account information. Potentially unsafe. Be sure to
  *   check_plain() before use.
@@ -15,8 +15,8 @@
  * @see template_preprocess_user_picture()
  */
 ?>
-<?php if ($picture): ?>
-  <div class="picture">
-    <?php print $picture; ?>
+<?php if ($user_picture): ?>
+  <div class="user-picture">
+    <?php print $user_picture; ?>
   </div>
 <?php endif; ?>
@@ -7,7 +7,7 @@
  *
  * Available variables:
- * - $picture: Image set by the user or the site's default. Will be linked
+ * - $user_picture: Image set by the user or the site's default. Will be linked
  *   depending on the viewer's permission to view the users profile page.
  * - $account: Array of account information. Potentially unsafe. Be sure to